@@ -1,3 +1,4 @@
+if(getRversion() >= '2.15.1') utils::globalVariables(c('CON')) 
 
 
 setGeneric("rangeMapExport", function(object,dirName, ...)  	    standardGeneric("rangeMapExport") )
@@ -11,7 +12,7 @@ setMethod("rangeMapExport",
 					'select name from sqlite_master where type = "table" and 
 						(tbl_name like "MAP_%")')$name
 		
-		if(length(mapnams) == 0) stop(.X.Msg("The project does not contain any MAP tables!"))
+		if(length(mapnams) == 0) stop(x.Msg("The project does not contain any MAP tables!"))
 		
 		wd = setwd(dirName)
 		
