@@ -57,10 +57,10 @@ setMethod("rangeMapSave",
 		# CHECKS
 		biotab = paste(object@BIO, object@biotab, sep = "")
 			if(!.dbtable.exists(object@CON,biotab) ) 
-			stop(.X.Msg( paste(sQuote(object@biotab), "is not a table of", sQuote(dbGetInfo(object@CON)$dbname))))
+			stop(x.Msg( paste(sQuote(object@biotab), "is not a table of", sQuote(dbGetInfo(object@CON)$dbname))))
 		# object@biotrait should exist as a field in biotab
 		if(!.dbfield.exists(object@CON,biotab, object@biotrait) ) 
-			stop(.X.Msg(paste(sQuote(object@biotrait), "is not a field of", sQuote(object@biotab))))
+			stop(x.Msg(paste(sQuote(object@biotrait), "is not a field of", sQuote(object@biotab))))
 		# fun should  be known by sqlite	
 		.sqlAggregate(FUN)
 				
@@ -83,11 +83,11 @@ setMethod("rangeMapSave",
 		RMQuery(object@CON, paste("CREATE INDEX", paste(tableName, "id", sep = "_") , "ON", tableName, "(id)") )
 		RMQuery(object@CON, paste("INSERT INTO" ,tableName, sql) )
 		
-		# out .X.Msg
+		# out x.Msg
 		return(.dbtable.exists(object@CON, tableName))
 			
 		
-		#cat(strwrap(sql, width = 100))
+		cat(strwrap(sql, width = 100))
 		}
 	)						
 
@@ -95,10 +95,10 @@ setMethod("rangeMapSave",
 		# CHECKS
 		biotab = paste(object@BIO, object@biotab, sep = "")
 			if(!.dbtable.exists(object@CON,biotab) ) 
-			stop(.X.Msg( paste(sQuote(object@biotab), "is not a table of", sQuote(dbGetInfo(object@CON)$dbname))))
+			stop(x.Msg( paste(sQuote(object@biotab), "is not a table of", sQuote(dbGetInfo(object@CON)$dbname))))
 		# object@biotrait should exist as a field in biotab
 		if(!.dbfield.exists(object@CON,biotab, object@biotrait) ) 
-			stop(.X.Msg(paste(sQuote(object@biotrait), "is not a field of", sQuote(object@biotab))))
+			stop(x.Msg(paste(sQuote(object@biotrait), "is not a field of", sQuote(object@biotab))))
 		
 		# BIO_tab name
 		biotab = paste(object@BIO, object@biotab, sep = "")
@@ -113,6 +113,10 @@ setMethod("rangeMapSave",
 		# fetch table
 		d = RMQuery(object@CON, sql)
 		
+		if(nrow(d) == 0) {
+			stop(x.Msg( paste("The map is going to be empty! Maybe the bioid in", sQuote(object@biotab), " BIO table was wrongly set.") )) }
+		
+		
 		# return list
 		split(d, d[, object@ID])
 }
@@ -141,7 +145,7 @@ setMethod("rangeMapSave",
 		RMQuery(object@CON, paste("CREATE INDEX", paste(tableName, "id", sep = "_") , "ON", tableName, "(id)") )
 		dbWriteTable(object@CON, tableName, X, row.names = FALSE, append = TRUE)
 		
-		#out .X.Msg
+		#out x.Msg
 		return(.dbtable.exists(object@CON, tableName))
 			
 		}
@@ -170,11 +174,11 @@ setMethod("rangeMapSave",
 		RMQuery(object@CON, paste("CREATE INDEX", paste(tableName, "id", sep = "_") , "ON", tableName, "(id)") )
 		dbWriteTable(object@CON, tableName, X, row.names = FALSE, append = TRUE)
 		
-		#out .X.Msg
+		#out x.Msg
 		return(.dbtable.exists(object@CON, tableName))
 			
 		}
-	)
+)
 
 # IMPORT RASTER	
 	
@@ -192,10 +196,10 @@ setMethod("rangeMapImport",
 	tableName = paste(object@MAP, object@tableName, sep = "")		
 		
 	cnv = canvas.fetch(object@CON)
-	.X.Msg("Converting canvas to polygons...")
+	x.Msg("Converting canvas to polygons...")
 	cnv = rasterToPolygons(raster(cnv))
 	
-	.X.Msg("Loading external MAP data...")
+	x.Msg("Loading external MAP data...")
 	rst = raster(object@path)
 		
 	# is there any other way to compare CRS-s ?	
@@ -203,33 +207,33 @@ setMethod("rangeMapImport",
 		warning(sQuote(filenam), " may have a different PROJ4 string;\n", "canvas:", CRSargs(CRS(proj4string(cnv))), "\n", filenam, ":", CRSargs(projection(rst, FALSE)) )
 	
 	rstp = as(as(rst, "SpatialGridDataFrame"), "SpatialPointsDataFrame") 
-	.X.Msg("Extracting Layer 1...")
+	x.Msg("Extracting Layer 1...")
 	rstp = rstp[which(!is.na(rstp@data[,1])), ]
 	
 	rstp@data$ptid = as.numeric(rownames(rstp@data)) # add point id
 	
-	.X.Msg(paste("Performing overlay: canvas polygons over", filenam, "...") )	
-	o = overlay(cnv, rstp)
+	x.Msg(paste("Performing overlay: canvas polygons over", filenam, "...") )	
+	o = overlay(cnv, rstp) # #TODO change with over
 	o$ptid = as.numeric(rownames(o))
 
 	o = merge(o, rstp@data, by = "ptid")
 	o$ptid = NULL
 	
-	.X.Msg("Agregating data...")
+	x.Msg("Agregating data...")
 	o = aggregate(o[, 2], list(o[,1]), FUN = FUN, na.rm = TRUE, ...)
 	
 	names(o) = c(object@ID, object@tableName) 
 
 	# build table and index
-	.X.Msg("Creating table and indexes...")
-	RMQuery(object@CON, paste("CREATE TABLE" ,tableName, "(", object@ID, "INTEGER,",object@tableName, "NUMERIC)"))
+	x.Msg("Creating table and indexes...")
+	RMQuery(object@CON, paste("CREATE TABLE" ,tableName, "(", object@ID, "INTEGER,",object@tableName, "FLOAT)"))
 	RMQuery(object@CON, paste("CREATE INDEX", paste(tableName, "id", sep = "_") , "ON", tableName, "(id)") )
 	dbWriteTable(object@CON, tableName, o, row.names = FALSE, append = TRUE)
 	
 	
 	res = .dbtable.exists(object@CON, tableName)
 	
-	if(res) .X.Msg(paste(sQuote(basename(object@path)), "imported"))
+	if(res) x.Msg(paste(sQuote(basename(object@path)), "imported"))
 	
 	return(res)	
 							
